==> zhongyan-activity-service-api-1.0.3-20211201.050917-66-sources.jar: cn/com/duiba/zhongyan/activity/service/api/remoteservice/activity/RemoteUserPrizeRecordService.java <==
package cn.com.duiba.zhongyan.activity.service.api.remoteservice.activity;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.zhongyan.activity.service.api.base.PageResult;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.UserPrizeRecordDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.WinnerRecordDTO;
import cn.com.duiba.zhongyan.activity.service.api.param.AddWinnerRecordParam;
import cn.com.duiba.zhongyan.activity.service.api.param.PrizeConditionParam;
import cn.com.duiba.zhongyan.activity.service.api.param.UserPrizeRecordPageQueryParam;

import java.util.List;

/**
 * @author xuanyu
 * @description: 用户中奖记录表对外服务
 * @date 2021/11/25 5:57 下午
 */
@AdvancedFeignClient
public interface RemoteUserPrizeRecordService {
    /**
     * 根据主键删除
     * @param id 主键id
     * @return 主键id
     */
    Long deleteByPrimaryKey(Long id);

    /**
     * 根据实体插入一条用户中奖记录
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 主键id
     */
    Long insert(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 选择性插入实体中不为null的属性
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 主键id
     */
    Long insertSelective(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据主键id查找记录
     * @param id 主键id
     * @return 一条用户中奖记录
     */
    UserPrizeRecordDTO selectByPrimaryKey(Long id);

    /**
     * 选择性更新实体中不为null的值
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 操作成功的记录条数
     */
    int updateByPrimaryKeySelective(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据主键id更新
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 操作成功的记录条数
     */
    int updateByPrimaryKey(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据查询参数返回中奖记录(含奖品名）,可补充返回奖品表的DTO
     * @param pageQueryParam 查询参数
     * @return
     */
    PageResult<UserPrizeRecordDTO> listUserPrizeRecordEntity(UserPrizeRecordPageQueryParam pageQueryParam) throws BizException;

    /**
     * 条件分页查询用户中奖记录
     * @param prizeConditionParam
     * @return
     */
    PageResult<UserPrizeRecordDTO> listPrizeRecordPageByConditions(PrizeConditionParam prizeConditionParam);

    /**
     * 条件分页查询用户中奖记录
     * @param userPrizeRecordPageQueryParam 用户中奖记录(含用户，奖品关联筛选）
     * @return 用户中奖记录
     */
    PageResult<WinnerRecordDTO> listUserPrizeRecordWithUser(UserPrizeRecordPageQueryParam userPrizeRecordPageQueryParam) throws BizException;

    /**
     * 更新未确认状态的中奖记录未已确认
     * @return 操作成功的条数
     */
    Integer confirmPrizeRecord(Long activityId) throws BizException;

    List<UserPrizeRecordDTO> listUserPrizeByUser(Long activityId, Long userId) throws BizException;


    /**
     * 根据用户id和活动id更新中奖记录
     * @param userPrizeRecordDTO
     * @return
     */
    int updateByUserIdAndActivityIdSelective(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据中奖记录id删除未确认状态的中奖记录
     * @param prizeRecordId 中奖记录id
     * @return 操作成功的条数
     */
    Integer deleteByPrimaryKeyAndStatus(Long prizeRecordId) throws BizException;

    /**
     * 根据活动id和userIdList批量查询用户中奖记录
     * @param activityId 活动id
     * @param userIdList 用户列表
     * @return 用户中奖记录
     */
    List<UserPrizeRecordDTO> listUserPrizeByUserIds(Long activityId,List<Long> userIdList) throws BizException;

    /**
     * 添加用户中奖记录
     * @param addWinnerRecordParam 添加中奖记录
     * @return 添加中奖记录
     */
    Boolean addWinnerPrizeRecord(AddWinnerRecordParam addWinnerRecordParam) throws BizException;

    /**
     * 批量查询用户中奖记录
     * @param userPrizeRecordDTOList 用户中奖记录
     * @return
     */
    Integer insertBatchUserRecord(List<UserPrizeRecordDTO> userPrizeRecordDTOList) throws BizException;
}

==> zhongyan-activity-service-api-1.0.3-20211201.094354-78-sources.jar: cn/com/duiba/zhongyan/activity/service/api/remoteservice/activity/RemoteUserPrizeRecordService.java <==
package cn.com.duiba.zhongyan.activity.service.api.remoteservice.activity;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.zhongyan.activity.service.api.base.PageResult;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.UserPrizeDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.UserPrizeRecordDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.WinnerRecordDTO;
import cn.com.duiba.zhongyan.activity.service.api.param.AddWinnerRecordParam;
import cn.com.duiba.zhongyan.activity.service.api.param.PrizeConditionParam;
import cn.com.duiba.zhongyan.activity.service.api.param.UserPrizeRecordPageQueryParam;

import java.util.List;

/**
 * @author xuanyu
 * @description: 用户中奖记录表对外服务
 * @date 2021/11/25 5:57 下午
 */
@AdvancedFeignClient
public interface RemoteUserPrizeRecordService {
    /**
     * 根据主键删除
     * @param id 主键id
     * @return 主键id
     */
    Long deleteByPrimaryKey(Long id);

    /**
     * 根据实体插入一条用户中奖记录
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 主键id
     */
    Long insert(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 选择性插入实体中不为null的属性
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 主键id
     */
    Long insertSelective(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据主键id查找记录
     * @param id 主键id
     * @return 一条用户中奖记录
     */
    UserPrizeRecordDTO selectByPrimaryKey(Long id);

    /**
     * 选择性更新实体中不为null的值
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 操作成功的记录条数
     */
    int updateByPrimaryKeySelective(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据主键id更新
     * @param userPrizeRecordDTO 用户中奖记录
     * @return 操作成功的记录条数
     */
    int updateByPrimaryKey(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据查询参数返回中奖记录(含奖品名）,可补充返回奖品表的DTO
     * @param pageQueryParam 查询参数
     * @return
     */
    PageResult<UserPrizeRecordDTO> listUserPrizeRecordEntity(UserPrizeRecordPageQueryParam pageQueryParam) throws BizException;



    /**
     * 分页查询奖品列表
     * @param prizeConditionParam
     * @return
     */
    PageResult<UserPrizeDTO> listPrizePageByConditions(PrizeConditionParam prizeConditionParam);

    /**
     * 条件分页查询用户中奖记录
     * @param userPrizeRecordPageQueryParam 用户中奖记录(含用户，奖品关联筛选）
     * @return 用户中奖记录
     */
    PageResult<WinnerRecordDTO> listUserPrizeRecordWithUser(UserPrizeRecordPageQueryParam userPrizeRecordPageQueryParam) throws BizException;

    /**
     *
     * @param userPrizeRecordPageQueryParam
     * @return
     * @throws BizException
     */
    Integer countUserPrizeRecordWithUser(UserPrizeRecordPageQueryParam userPrizeRecordPageQueryParam) throws BizException;

    /**
     * 更新未确认状态的中奖记录未已确认
     * @return 操作成功的条数
     */
    Integer confirmPrizeRecord(Long activityId) throws BizException;

    List<UserPrizeRecordDTO> listUserPrizeByUser(Long activityId, Long userId) throws BizException;


    /**
     * 根据用户id和活动id更新中奖记录
     * @param userPrizeRecordDTO
     * @return
     */
    int updateByUserIdAndActivityIdSelective(UserPrizeRecordDTO userPrizeRecordDTO);

    /**
     * 根据中奖记录id删除未确认状态的中奖记录
     * @param prizeRecordId 中奖记录id
     * @return 操作成功的条数
     */
    Integer deleteByPrimaryKeyAndStatus(Long prizeRecordId) throws BizException;

    /**
     * 根据活动id和userIdList批量查询用户中奖记录
     * @param activityId 活动id
     * @param userIdList 用户列表
     * @return 用户中奖记录
     */
    List<UserPrizeRecordDTO> listUserPrizeByUserIds(Long activityId,List<Long> userIdList) throws BizException;

    /**
     * 添加用户中奖记录
     * @param addWinnerRecordParam 添加中奖记录
     * @return 添加中奖记录
     */
    Boolean addWinnerPrizeRecord(AddWinnerRecordParam addWinnerRecordParam) throws BizException;

    /**
     * 批量查询用户中奖记录
     * @param userPrizeRecordDTOList 用户中奖记录
     * @return
     */
    Integer insertBatchUserRecord(List<UserPrizeRecordDTO> userPrizeRecordDTOList) throws BizException;
}
